@@ -1,3 +1,4 @@
+import json
 from dataclasses import dataclass, field
 from enum import Enum, auto
 from types import DynamicClassAttribute
@@ -5,7 +6,7 @@ from typing import Any
 
 
 @dataclass
-class Field(object):
+class EnumField:
     """
     枚举字段类
     """
@@ -19,32 +20,42 @@ class EnumBase(Enum):
     枚举基类
     """
 
+    @classmethod
+    def _missing_(cls, value: object) -> Any:
+        result = list(filter(lambda d: d.value == value, cls))  # type: ignore
+        return result[0] if result else None
+
     @DynamicClassAttribute
-    def value(self):
+    def value(self) -> Any:
         """
         获取枚举的值
         Returns:
 
         """
-        if isinstance(self._value_, Field):
+        if isinstance(self._value_, EnumField):
             return self._value_.value
         return self._value_
 
     @DynamicClassAttribute
-    def desc(self):
+    def desc(self) -> str:
         """
         获取枚举值的描述
         Returns:
 
         """
-        if isinstance(self._value_, Field):
+        if isinstance(self._value_, EnumField):
             return self._value_.desc
         else:
             return ""
 
     @classmethod
-    def list(cls):
-        return list(map(lambda c: c.value, cls))
+    def list(cls) -> list:
+        return [c.value for c in cls]
+
+    @classmethod
+    def to_desc(cls) -> str:
+        data = {d.value: d.desc for d in cls}
+        return json.dumps(data, ensure_ascii=False)
 
 
 class RespCodeEnum(EnumBase):
@@ -52,10 +63,9 @@ class RespCodeEnum(EnumBase):
     响应码枚举
     """
 
-    SUCCESS = Field(10000, desc="成功")
-    FAILED = Field(40000, desc="失败")
-
-    PARAM_FAILED = Field(40001, desc="参数校验失败")
+    SUCCESS = EnumField(10000, desc="成功")
+    FAILED = EnumField(40000, desc="失败")
+    PARAM_FAILED = EnumField(40001, desc="参数校验失败")
 
 
 class ParamEnum(EnumBase):
@@ -63,6 +73,6 @@ class ParamEnum(EnumBase):
     参数位置
     """
 
-    JSON = Field("json")
-    FORM = Field("form")
-    QUERY = Field("query")
+    JSON = EnumField("json")
+    FORM = EnumField("form")
+    QUERY = EnumField("query")
