@@ -29,7 +29,7 @@ class InterceptHandler(logging.StreamHandler):
             depth += 1
 
         fmt = "%(message)s"
-        sanic_access_fmt = "[%(host)s]: %(request)s %(message)s %(status)d %(byte)s %(time)s args: %(req_args)s"
+        sanic_access_fmt = "[%(host)s]: %(request)s %(message)s %(status)d %(byte)s %(time)s%(req_args)s"
         fmt = fmt if record.name != "sanic.access" else sanic_access_fmt
         formatter = logging.Formatter(fmt=fmt)
         msg = formatter.format(record)
@@ -37,8 +37,10 @@ class InterceptHandler(logging.StreamHandler):
         req_id = self.get_req_id()
 
         if "Dispatching signal" not in msg:
-            etxra_data = dict(type=record.name, req_id=req_id)
-            logger.bind(**etxra_data).opt(depth=depth, exception=record.exc_info).log(level, msg)
+            etxra_data = {"type": record.name, "req_id": req_id}
+            logger.bind(**etxra_data).opt(depth=depth, exception=record.exc_info).log(
+                level, msg
+            )
 
     @staticmethod
     def get_req_id():
@@ -68,9 +70,9 @@ class InterceptHandler(logging.StreamHandler):
 
         if name == "tortoise.db_client":
             if (
-                    record.levelname == "DEBUG"
-                    and not message.startswith("Created connection pool")
-                    and not message.startswith("Closed connection pool")
+                record.levelname == "DEBUG"
+                and not message.startswith("Created connection pool")
+                and not message.startswith("Closed connection pool")
             ):
                 message = highlight(message, postgres, terminal_formatter).rstrip()
 
